==> dojo_1.5.0+dfsg.orig.tar.gz: dojo-release-1.5.0-src+dfsg/dijit/_editor/nls/sl/commands.js <==
({
	'bold': 'Krepko',
	'copy': 'Prekopiraj',
	'cut': 'Izreži',
	'delete': 'Izbriši',
	'indent': 'Zamik',
	'insertHorizontalRule': 'Vodoravno ravnilo',
	'insertOrderedList': 'Oštevilčen seznam',
	'insertUnorderedList': 'Naštevni seznam',
	'italic': 'Ležeče',
	'justifyCenter': 'Poravnaj na sredino',
	'justifyFull': 'Obojestranska poravnava',
	'justifyLeft': 'Poravnaj levo',
	'justifyRight': 'Poravnaj desno',
	'outdent': 'Viseč odstavek',
	'paste': 'Prilepi',
	'redo': 'Znova uveljavi',
	'removeFormat': 'Odstrani obliko zapisa',
	'selectAll': 'Izberi vse',
	'strikethrough': 'Prečrtano',
	'subscript': 'Podpisano',
	'superscript': 'Nadpisano',
	'underline': 'Podčrtano',
	'undo': 'Razveljavi',
	'unlink': 'Odstrani povezavo',
	'createLink': 'Ustvari povezavo',
	'toggleDir': 'Preklopi na usmeritev',
	'insertImage': 'Vstavi sliko',
	'insertTable': 'Vstavi/uredi tabelo',
	'toggleTableBorder': 'Preklopi na rob tabele',
	'deleteTable': 'Izbriši tabelo',
	'tableProp': 'Lastnost tabele',
	'htmlToggle': 'Izvorna koda HTML',
	'foreColor': 'Barva ospredja',
	'hiliteColor': 'Barva ozadja',
	'plainFormatBlock': 'Slog odstavka',
	'formatBlock': 'Slog odstavka',
	'fontSize': 'Velikost pisave',
	'fontName': 'Ime pisave',
	'tabIndent': 'Zamik tabulatorja',
	"fullScreen": "Preklopi na celozaslonski način",
	"viewSource": "Prikaži izvorno kodo HTML",
	"print": "Natisni",
	"newPage": "Nova stran",
	/* Error messages */
	'systemShortcut': 'Dejanje "${0}" lahko v vašem brskalniku uporabite samo z bližnjico na tipkovnici. Uporabite ${1}.'
})

==> dojo_1.7.2+dfsg.orig.tar.gz: dojo-release-1.7.2-src+dfsg/dijit/_editor/nls/sl/commands.js <==
define(
//begin v1.x content
({
	'bold': 'Krepko',
	'copy': 'Prekopiraj',
	'cut': 'Izreži',
	'delete': 'Izbriši',
	'indent': 'Zamik',
	'insertHorizontalRule': 'Vodoravno ravnilo',
	'insertOrderedList': 'Oštevilčen seznam',
	'insertUnorderedList': 'Naštevni seznam',
	'italic': 'Ležeče',
	'justifyCenter': 'Poravnaj na sredino',
	'justifyFull': 'Poravnaj obojestransko',
	'justifyLeft': 'Poravnaj levo',
	'justifyRight': 'Poravnaj desno',
	'outdent': 'Primakni',
	'paste': 'Prilepi',
	'redo': 'Znova uveljavi',
	'removeFormat': 'Odstrani oblikovanje',
	'selectAll': 'Izberi vse',
	'strikethrough': 'Prečrtano',
	'subscript': 'Podpisano',
	'superscript': 'Nadpisano',
	'underline': 'Podčrtano',
	'undo': 'Razveljavi',
	'unlink': 'Odstrani povezavo',
	'createLink': 'Ustvari povezavo',
	'toggleDir': 'Preklopi smer',
	'insertImage': 'Vstavi sliko',
	'insertTable': 'Vstavi/uredi tabelo',
	'toggleTableBorder': 'Preklopi na rob tabele',
	'deleteTable': 'Izbriši tabelo',
	'tableProp': 'Lastnost tabele',
	'htmlToggle': 'Izvorna koda HTML',
	'foreColor': 'Barva ospredja',
	'hiliteColor': 'Barva ozadja',
	'plainFormatBlock': 'Slog odstavka',
	'formatBlock': 'Slog odstavka',
	'fontSize': 'Velikost pisave',
	'fontName': 'Ime pisave',
	'tabIndent': 'Zamik tabulatorja',
	"fullScreen": "Preklopi na celozaslonski način",
	"viewSource": "Prikaži izvorno kodo HTML",
	"print": "Natisni",
	"newPage": "Nova stran",
	/* Error messages */
	'systemShortcut': 'Dejanje "${0}" lahko v vašem brskalniku uporabite samo z bližnjico na tipkovnici. Uporabite ${1}.'
})
//end v1.x content
);
